@@ -47,11 +47,22 @@ def sync_customers():
     products = ["business_access", "business_plus"] #, "airfiber"]
     for product in products:
         customers = core.get_customers_crm(product)
+
         for customer in customers:
+            print(customer)
             name = customer['ident'].lower()
             product_name = customer['produit_nom']
             refnum = customer['refnum_primaire']
-            core.sync_customer(name, product_name, refnum)
+            exists = core.get_customers_si(
+                identifier="name",
+                value=name
+            )
+            if exists:
+                if exists[0]['refnum'] != refnum or exists[0]['product'] != product_name:
+                    core.update_customer(name, product_name, refnum)
+            else:
+                core.create_customer(name, product_name, refnum)
+            #core.sync_customer(name, product_name, refnum)
     LOGS.logger.info("Sync customers from CRM -- END")
 
 
